pub struct MockOrganizationReportsApi {
OrganizationReportsApi_expectations: MockOrganizationReportsApi_OrganizationReportsApi,
}Fields
OrganizationReportsApi_expectations: MockOrganizationReportsApi_OrganizationReportsApiImplementations
Sourceimpl MockOrganizationReportsApi
impl MockOrganizationReportsApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockOrganizationReportsApi
impl MockOrganizationReportsApi
Sourcepub fn expect_azure_validate_file(&mut self) -> &mut Expectation
pub fn expect_azure_validate_file(&mut self) -> &mut Expectation
Create an Expectation for mocking the azure_validate_file method
Sourcepub fn expect_create_organization_report(&mut self) -> &mut Expectation
pub fn expect_create_organization_report(&mut self) -> &mut Expectation
Create an Expectation for mocking the create_organization_report method
Sourcepub fn expect_delete_organization_report(&mut self) -> &mut Expectation
pub fn expect_delete_organization_report(&mut self) -> &mut Expectation
Create an Expectation for mocking the delete_organization_report method
Sourcepub fn expect_download_report_file(&mut self) -> &mut Expectation
pub fn expect_download_report_file(&mut self) -> &mut Expectation
Create an Expectation for mocking the download_report_file method
Sourcepub fn expect_get_latest_organization_report(&mut self) -> &mut Expectation
pub fn expect_get_latest_organization_report(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_latest_organization_report method
Sourcepub fn expect_get_organization_report(&mut self) -> &mut Expectation
pub fn expect_get_organization_report(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_organization_report method
Sourcepub fn expect_get_organization_report_application_data(
&mut self,
) -> &mut Expectation
pub fn expect_get_organization_report_application_data( &mut self, ) -> &mut Expectation
Create an Expectation for mocking the get_organization_report_application_data method
Sourcepub fn expect_get_organization_report_summary(&mut self) -> &mut Expectation
pub fn expect_get_organization_report_summary(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_organization_report_summary method
Sourcepub fn expect_get_organization_report_summary_data_by_date_range(
&mut self,
) -> &mut Expectation
pub fn expect_get_organization_report_summary_data_by_date_range( &mut self, ) -> &mut Expectation
Create an Expectation for mocking the get_organization_report_summary_data_by_date_range method
Sourcepub fn expect_renew_file_upload_url(&mut self) -> &mut Expectation
pub fn expect_renew_file_upload_url(&mut self) -> &mut Expectation
Create an Expectation for mocking the renew_file_upload_url method
Sourcepub fn expect_update_organization_report(&mut self) -> &mut Expectation
pub fn expect_update_organization_report(&mut self) -> &mut Expectation
Create an Expectation for mocking the update_organization_report method
Sourcepub fn expect_update_organization_report_application_data(
&mut self,
) -> &mut Expectation
pub fn expect_update_organization_report_application_data( &mut self, ) -> &mut Expectation
Create an Expectation for mocking the update_organization_report_application_data method
Sourcepub fn expect_update_organization_report_summary(&mut self) -> &mut Expectation
pub fn expect_update_organization_report_summary(&mut self) -> &mut Expectation
Create an Expectation for mocking the update_organization_report_summary method
Sourcepub fn expect_upload_report_file(&mut self) -> &mut Expectation
pub fn expect_upload_report_file(&mut self) -> &mut Expectation
Create an Expectation for mocking the upload_report_file method